@@ -13,9 +13,11 @@ static void
 usage()
 {
     fprintf(stderr,
-        "usage: %s [-vV] [-f fstype] [-i imgtype] [-o imgoffset] image [images]\n",
+        "usage: %s [-vV] [-f fstype] [-i imgtype] [-b dev_sector_size] [-o imgoffset] image [images]\n",
         progname);
     fprintf(stderr, "\t-i imgtype: The format of the image file\n");
+    tsk_fprintf(stderr,
+        "\t-b dev_sector_size: The size (in bytes) of the device sectors\n");
     fprintf(stderr,
         "\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
     fprintf(stderr, "\t-v: verbose output to stderr\n");
@@ -34,34 +36,45 @@ main(int argc, char **argv)
     TSK_IMG_TYPE_ENUM imgtype = TSK_IMG_TYPE_DETECT;
     TSK_IMG_INFO *img;
 
-    TSK_OFF_T imgoff = 0;
+    TSK_OFF_T imgaddr = 0;
     TSK_FS_TYPE_ENUM fstype = TSK_FS_TYPE_DETECT;
     TSK_FS_INFO *fs;
 
     int ch;
     TSK_TCHAR **argv;
-    
+    unsigned int ssize = 0;
+    TSK_TCHAR *cp;
+
 #ifdef TSK_WIN32
     // On Windows, get the wide arguments (mingw doesn't support wmain)
     argv = CommandLineToArgvW(GetCommandLineW(), &argc);
-    if( argv == NULL) {    
+    if (argv == NULL) {
         fprintf(stderr, "Error getting wide arguments\n");
         exit(1);
     }
 #else
-    argv = (TSK_TCHAR **)argv1;
+    argv = (TSK_TCHAR **) argv1;
 #endif
-    
+
 
     progname = argv[0];
 
-    while ((ch = GETOPT(argc, argv, "f:i:o:vV")) > 0) {
+    while ((ch = GETOPT(argc, argv, "b:f:i:o:vV")) > 0) {
         switch (ch) {
         case '?':
         default:
             fprintf(stderr, "Invalid argument: %s\n", argv[OPTIND]);
             usage();
-
+        case _TSK_T('b'):
+            ssize = (unsigned int) TSTRTOUL(OPTARG, &cp, 0);
+            if (*cp || *cp == *OPTARG || ssize < 1) {
+                TFPRINTF(stderr,
+                    _TSK_T
+                    ("invalid argument: sector size must be positive: %s\n"),
+                    OPTARG);
+                usage();
+            }
+            break;
         case 'f':
             if (TSTRCMP(OPTARG, _TSK_T("list")) == 0) {
                 tsk_fs_type_print(stderr);
@@ -89,7 +102,7 @@ main(int argc, char **argv)
             break;
 
         case 'o':
-            if ((imgoff = tsk_parse_offset(OPTARG)) == -1) {
+            if ((imgaddr = tsk_parse_offset(OPTARG)) == -1) {
                 tsk_error_print(stderr);
                 exit(1);
             }
@@ -113,7 +126,7 @@ main(int argc, char **argv)
 
     img =
         img_open(imgoff, argc - OPTIND,
-        (const char **) &argv[OPTIND], imgtype);
+        (const char **) &argv[OPTIND], imgtype, ssize);
     if (img == NULL) {
         tsk_error_print(stderr);
         exit(1);
