@@ -34,7 +34,7 @@ usage()
 {
     TFPRINTF(stderr,
         _TSK_T
-        ("usage: %s [-emOpvV] [-aAlLzZ] [-f fstype] [-i imgtype] [-o imgoffset] [-s seconds] image [images] [inum[-end]]\n"),
+        ("usage: %s [-emOpvV] [-aAlLzZ] [-f fstype] [-i imgtype] [-b dev_sector_size] [-o imgoffset] [-s seconds] image [images] [inum[-end]]\n"),
         progname);
     tsk_fprintf(stderr, "\t-e: Display all inodes\n");
     tsk_fprintf(stderr, "\t-m: Display output in the mactime format\n");
@@ -52,6 +52,8 @@ usage()
     tsk_fprintf(stderr, "\t-Z: Used inodes (ctime is not 0)\n");
     tsk_fprintf(stderr,
         "\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
+    tsk_fprintf(stderr,
+        "\t-b dev_sector_size: The size (in bytes) of the device sectors\n");
     tsk_fprintf(stderr,
         "\t-f fstype: File system type (use '-f list' for supported types)\n");
     tsk_fprintf(stderr,
@@ -65,12 +67,12 @@ usage()
 
 /* main - open file system, list inode info */
 int
-main(int argc, char ** argv1)
+main(int argc, char **argv1)
 {
     TSK_IMG_TYPE_ENUM imgtype = TSK_IMG_TYPE_DETECT;
     TSK_IMG_INFO *img;
 
-    TSK_OFF_T imgoff = 0;
+    TSK_OFF_T imgaddr = 0;
     TSK_FS_TYPE_ENUM fstype = TSK_FS_TYPE_DETECT;
     TSK_FS_INFO *fs;
 
@@ -83,17 +85,18 @@ main(int argc, char ** argv1)
     TSK_TCHAR *image = NULL;
     int32_t sec_skew = 0;
     TSK_TCHAR **argv;
-    
+    unsigned int ssize = 0;
+
 #ifdef TSK_WIN32
     // On Windows, get the wide arguments (mingw doesn't support wmain)
     argv = CommandLineToArgvW(GetCommandLineW(), &argc);
-    if( argv == NULL) {    
+    if (argv == NULL) {
         fprintf(stderr, "Error getting wide arguments\n");
         exit(1);
     }
 #else
-    argv = (TSK_TCHAR **)argv1;
-#endif    
+    argv = (TSK_TCHAR **) argv1;
+#endif
 
     progname = argv[0];
     setlocale(LC_ALL, "");
@@ -102,13 +105,24 @@ main(int argc, char ** argv1)
      * Provide convenience options for the most commonly selected feature
      * combinations.
      */
-    while ((ch = GETOPT(argc, argv, _TSK_T("aAef:i:lLmo:Oprs:vVzZ"))) > 0) {
+    while ((ch =
+            GETOPT(argc, argv, _TSK_T("aAb:ef:i:lLmo:Oprs:vVzZ"))) > 0) {
         switch (ch) {
         case _TSK_T('?'):
         default:
             TFPRINTF(stderr, _TSK_T("Invalid argument: %s\n"),
                 argv[OPTIND]);
             usage();
+        case _TSK_T('b'):
+            ssize = (unsigned int) TSTRTOUL(OPTARG, &cp, 0);
+            if (*cp || *cp == *OPTARG || ssize < 1) {
+                TFPRINTF(stderr,
+                    _TSK_T
+                    ("invalid argument: sector size must be positive: %s\n"),
+                    OPTARG);
+                usage();
+            }
+            break;
         case _TSK_T('f'):
             if (TSTRCMP(OPTARG, _TSK_T("list")) == 0) {
                 tsk_fs_type_print(stderr);
@@ -141,7 +155,7 @@ main(int argc, char ** argv1)
             ils_flags |= TSK_FS_ILS_MAC;
             break;
         case _TSK_T('o'):
-            if ((imgoff = tsk_parse_offset(OPTARG)) == -1) {
+            if ((imgaddr = tsk_parse_offset(OPTARG)) == -1) {
                 tsk_error_print(stderr);
                 exit(1);
             }
@@ -212,16 +226,15 @@ main(int argc, char ** argv1)
             /* Not a number - consider it a file name */
             image = argv[OPTIND];
             if ((img =
-                    tsk_img_open(argc - OPTIND,
-                        (const TSK_TCHAR **) &argv[OPTIND],
-                        imgtype)) == NULL) {
+                    tsk_img_open(argc - OPTIND, &argv[OPTIND],
+                        imgtype, ssize)) == NULL) {
                 tsk_error_print(stderr);
                 exit(1);
             }
-            if (imgoff >= img->size) {
+            if ((imgaddr * img->sector_size) >= img->size) {
                 tsk_fprintf(stderr,
                     "Sector offset supplied is larger than disk image (maximum: %"
-                    PRIu64 ")\n", img->size / 512);
+                    PRIu64 ")\n", img->size / img->sector_size);
                 exit(1);
             }
         }
@@ -231,16 +244,15 @@ main(int argc, char ** argv1)
             set_range = 0;
             image = argv[OPTIND];
             if ((img =
-                    tsk_img_open(argc - OPTIND - 1,
-                        (const TSK_TCHAR **) &argv[OPTIND],
-                        imgtype)) == NULL) {
+                    tsk_img_open(argc - OPTIND - 1, &argv[OPTIND],
+                        imgtype, ssize)) == NULL) {
                 tsk_error_print(stderr);
                 exit(1);
             }
-            if (imgoff >= img->size) {
+            if ((imgaddr * img->sector_size) >= img->size) {
                 tsk_fprintf(stderr,
                     "Sector offset supplied is larger than disk image (maximum: %"
-                    PRIu64 ")\n", img->size / 512);
+                    PRIu64 ")\n", img->size / img->sector_size);
                 exit(1);
             }
         }
@@ -255,16 +267,15 @@ main(int argc, char ** argv1)
             *dash = _TSK_T('-');
             image = argv[OPTIND];
             if ((img =
-                    tsk_img_open(argc - OPTIND,
-                        (const TSK_TCHAR **) &argv[OPTIND],
-                        imgtype)) == NULL) {
+                    tsk_img_open(argc - OPTIND, &argv[OPTIND],
+                        imgtype, ssize)) == NULL) {
                 tsk_error_print(stderr);
                 exit(1);
             }
-            if (imgoff >= img->size) {
+            if ((imgaddr * img->sector_size) >= img->size) {
                 tsk_fprintf(stderr,
                     "Sector offset supplied is larger than disk image (maximum: %"
-                    PRIu64 ")\n", img->size / 512);
+                    PRIu64 ")\n", img->size / img->sector_size);
                 exit(1);
             }
         }
@@ -277,16 +288,15 @@ main(int argc, char ** argv1)
                 *dash = '-';
                 image = argv[OPTIND];
                 if ((img =
-                        tsk_img_open(argc - OPTIND,
-                            (const TSK_TCHAR **) &argv[OPTIND],
-                            imgtype)) == NULL) {
+                        tsk_img_open(argc - OPTIND, &argv[OPTIND],
+                            imgtype, ssize)) == NULL) {
                     tsk_error_print(stderr);
                     exit(1);
                 }
-                if (imgoff >= img->size) {
+                if ((imgaddr * img->sector_size) >= img->size) {
                     tsk_fprintf(stderr,
                         "Sector offset supplied is larger than disk image (maximum: %"
-                        PRIu64 ")\n", img->size / 512);
+                        PRIu64 ")\n", img->size / img->sector_size);
                     exit(1);
                 }
             }
@@ -295,23 +305,22 @@ main(int argc, char ** argv1)
                 /* It was a block range, so do not include it in the open */
                 image = argv[OPTIND];
                 if ((img =
-                        tsk_img_open(argc - OPTIND - 1,
-                            (const TSK_TCHAR **) &argv[OPTIND],
-                            imgtype)) == NULL) {
+                        tsk_img_open(argc - OPTIND - 1, &argv[OPTIND],
+                            imgtype, ssize)) == NULL) {
                     tsk_error_print(stderr);
                     exit(1);
                 }
-                if (imgoff >= img->size) {
+                if ((imgaddr * img->sector_size) >= img->size) {
                     tsk_fprintf(stderr,
                         "Sector offset supplied is larger than disk image (maximum: %"
-                        PRIu64 ")\n", img->size / 512);
+                        PRIu64 ")\n", img->size / img->sector_size);
                     exit(1);
                 }
             }
         }
     }
 
-    if ((fs = tsk_fs_open_img(img, imgoff, fstype)) == NULL) {
+    if ((fs = tsk_fs_open_img(img, imgaddr * img->sector_size, fstype)) == NULL) {
         tsk_error_print(stderr);
         if (tsk_errno == TSK_ERR_FS_UNSUPTYPE)
             tsk_fs_type_print(stderr);
