@@ -534,7 +534,7 @@ print_strings (const char *filename, FILE *stream, uint64_t address,
 	       uint64_t stop_point, int magiccount, char *magic)
 {
   char *buf = (char *) malloc (sizeof (char) * (string_min + 1));
-  if (malloc == NULL) {
+  if (buf == NULL) {
       fprintf(stderr, "Error allocating memory\n");
       return;
   }
