@@ -2,7 +2,7 @@
  ** The Sleuth Kit 
  **
  ** Brian Carrier [carrier <at> sleuthkit [dot] org]
- ** Copyright (c) 2010 Brian Carrier.  All Rights reserved
+ ** Copyright (c) 2010-2011 Brian Carrier.  All Rights reserved
  **
  ** This software is distributed under the Common Public License 1.0
  **
@@ -118,6 +118,18 @@ void
 }
 
 
+/**
+ * @return The size of the image in bytes or -1 if the 
+ * image is not open.
+ */
+TSK_OFF_T TskAuto::getImageSize() const
+{
+    if (m_img_info == NULL)
+        return -1;
+
+    return m_img_info->size;
+}
+
 /**
  * Starts in sector 0 of the opened disk images and looks for a 
  * volume or file system. Will call processFile() on each file
@@ -132,12 +144,8 @@ uint8_t TskAuto::findFilesInImg()
         snprintf(tsk_errstr, TSK_ERRSTR_L, "findFilesInImg\n");
         return 1;
     }
-    if (findFilesInVs(0)) {
-        tsk_error_print(stderr);
-        return 1;
-    }
 
-    return 0;
+    return findFilesInVs(0);
 }
 
 
@@ -177,7 +185,7 @@ TSK_WALK_RET_ENUM
 
 
 /**
- * Starts in a specified sector of the opened disk images and looks for a 
+ * Starts in a specified byte offset of the opened disk images and looks for a 
  * volume system or file system. Will call processFile() on each file
  * that is found. 
  * @param a_start Byte offset to start analyzing from. 
@@ -199,9 +207,13 @@ uint8_t TskAuto::findFilesInVs(TSK_OFF_T a_start, TSK_VS_TYPE_ENUM a_vtype)
     if ((vs_info =
             tsk_vs_open(m_img_info, a_start,
                 a_vtype)) == NULL) {
+        char msg[1024];
+        snprintf(msg, 1024, "Unable to open volume system at offset %"PRIuOFF" (%s)",
+                a_start, tsk_error_get());
+
         if (tsk_verbose)
-            fprintf(stderr,
-                "Error determining volume system -- trying file systems\n");
+            fprintf(stderr, "%s\n", msg);
+        handleNotification(msg);
 
         /* There was no volume system, but there could be a file system */
         tsk_error_reset();
@@ -228,8 +240,8 @@ uint8_t TskAuto::findFilesInVs(TSK_OFF_T a_start, TSK_VS_TYPE_ENUM a_vtype)
 }
 
 /**
- * Starts in a specified sector of the opened disk images and looks for a 
- * volume system or file system. Will call processFile() on each file
+ * Starts at a specified byte offset of the opened disk images and looks
+ * for a volume or file system. Will call processFile() on each file 
  * that is found. 
  * @param a_start Byte offset to start analyzing from. 
  * @return 1 on error, 0 on success
@@ -241,9 +253,9 @@ uint8_t TskAuto::findFilesInVs(TSK_OFF_T a_start)
 
 
 /** 
- * Starts in a specified sector of the opened disk images and looks for a 
- * file system. Will call processFile() on each file
- * that is found.  Same as findFilesInFs, but gives more detailed return values.
+ * Starts at a specified byte offset of the opened disk images and looks
+ * for a file system. Will call processFile() on each file that is found. 
+ * Same as findFilesInFs, but gives more detailed return values.
  * @param a_start Byte offset to start analyzing from. 
  * @param a_ftype File system type.
  * @returns values that allow the caller to differentiate stop from ok.  
@@ -262,7 +274,13 @@ TSK_RETVAL_ENUM TskAuto::findFilesInFsRet(TSK_OFF_T a_start, TSK_FS_TYPE_ENUM a_
     /* Try it as a file system */
     if ((fs_info =
             tsk_fs_open_img(m_img_info, a_start, a_ftype)) == NULL) {
-        tsk_error_print(stderr);
+        char msg[1024];
+        snprintf(msg, 1024, "Unable to open file system at offset %"PRIuOFF" (%s)",
+                a_start, tsk_error_get());
+
+        if (tsk_verbose)
+            fprintf(stderr, "%s\n", msg);
+        handleNotification(msg);
 
         /* We could do some carving on the volume data at this point */
 
@@ -276,9 +294,8 @@ TSK_RETVAL_ENUM TskAuto::findFilesInFsRet(TSK_OFF_T a_start, TSK_FS_TYPE_ENUM a_
 }
 
 /** 
- * Starts in a specified sector of the opened disk images and looks for a 
- * file system. Will call processFile() on each file
- * that is found. 
+ * Starts at a specified byte offset of the opened disk images and looks
+ * for a file system. Will call processFile() on each file that is found. 
  *
  * @param a_start Byte offset of file system starting location.
  *
@@ -292,11 +309,28 @@ uint8_t TskAuto::findFilesInFs(TSK_OFF_T a_start)
         return 0;
 }
 
+/** 
+ * Processes the file system represented by the given TSK_FS_INFO
+ * pointer. Will Call processFile() on each file that is found.
+ *
+ * @param a_fs_info Pointer to a previously opened file system.
+ *
+ * @returns 1 on error and 0 on success
+ */
+uint8_t TskAuto::findFilesInFs(TSK_FS_INFO *a_fs_info)
+{
+    if (a_fs_info == NULL)
+        return 1;
+
+    if (findFilesInFsInt(a_fs_info, a_fs_info->root_inum) == TSK_ERR)
+        return 1;
+    else
+        return 0;
+}
 
 /** 
- * Starts in a specified sector of the opened disk images and looks for a 
- * file system. Will call processFile() on each file
- * that is found. 
+ * Starts at a specified byte offset of the opened disk images and looks
+ * for a file system. Will call processFile() on each file that is found. 
  *
  * @param a_start Byte offset of file system starting location.
  * @param a_ftype Type of file system that is located at the offset.
@@ -312,7 +346,7 @@ uint8_t TskAuto::findFilesInFs(TSK_OFF_T a_start, TSK_FS_TYPE_ENUM a_ftype)
 }
 
 /** 
- * Starts in a specified sector of the opened disk images and looks for a 
+ * Starts at a specified byte offset of the opened disk images and looks for a 
  * file system. Will start processing the file system at a specified 
  * file system. Will call processFile() on each file
  * that is found in that directory. 
@@ -338,7 +372,14 @@ uint8_t TskAuto::findFilesInFs(TSK_OFF_T a_start, TSK_FS_TYPE_ENUM a_ftype, TSK_
     if ((fs_info =
             tsk_fs_open_img(m_img_info, a_start,
                 a_ftype)) == NULL) {
-        tsk_error_print(stderr);
+
+        char msg[1024];
+        snprintf(msg, 1024, "Unable to open file system at offset %"PRIuOFF" (%s)",
+                a_start, tsk_error_get());
+
+        if (tsk_verbose)
+            fprintf(stderr, "%s\n", msg);
+        handleNotification(msg);
 
         /* We could do some carving on the volume data at this point */
 
@@ -355,7 +396,7 @@ uint8_t TskAuto::findFilesInFs(TSK_OFF_T a_start, TSK_FS_TYPE_ENUM a_ftype, TSK_
 
 
 /** 
- * Starts in a specified sector of the opened disk images and looks for a 
+ * Starts at a specified byte offset of the opened disk images and looks for a 
  * file system. Will start processing the file system at a specified 
  * file system. Will call processFile() on each file
  * that is found in that directory. 
@@ -410,7 +451,15 @@ TSK_RETVAL_ENUM
     if (tsk_fs_dir_walk(a_fs_info, a_inum,
             (TSK_FS_DIR_WALK_FLAG_ENUM) (TSK_FS_DIR_WALK_FLAG_RECURSE |
                 m_fileFilterFlags), dirWalkCb, this)) {
-        tsk_error_print(stderr);
+
+        char msg[1024];
+        snprintf(msg, 1024, "Error walking directory in file system at offset %"PRIuOFF" (%s)",
+                a_fs_info->offset, tsk_error_get());
+
+        if (tsk_verbose)
+            fprintf(stderr, "%s\n", msg);
+        handleNotification(msg);
+
         return TSK_ERR;
     }
 
@@ -488,7 +537,7 @@ uint8_t TskAuto::isFATSystemFiles(TSK_FS_FILE * a_fs_file)
 uint8_t TskAuto::isDotDir(TSK_FS_FILE * a_fs_file, const char *a_path)
 {
     if ((!a_fs_file) || (!a_fs_file->name)
-        || ((a_fs_file->name->flags & TSK_FS_NAME_TYPE_DIR) == 0))
+        || (a_fs_file->name->type != TSK_FS_NAME_TYPE_DIR))
         return 0;
 
     if ((a_fs_file->name->name_size >= 2)
@@ -509,11 +558,17 @@ uint8_t TskAuto::isDotDir(TSK_FS_FILE * a_fs_file, const char *a_path)
  */
 uint8_t TskAuto::isDir(TSK_FS_FILE * a_fs_file)
 {
-    if ((a_fs_file) && (a_fs_file->name)
-        && (a_fs_file->name->type == TSK_FS_NAME_TYPE_DIR))
-        return 1;
-    else
-        return 0;
+    if ((a_fs_file) && (a_fs_file->name)) {
+        if (a_fs_file->name->type == TSK_FS_NAME_TYPE_DIR) {
+            return 1;
+        }
+        else if (a_fs_file->name->type == TSK_FS_NAME_TYPE_UNDEF) {
+            if ((a_fs_file->meta) && (a_fs_file->meta->type == TSK_FS_META_TYPE_DIR)) {
+                return 1;
+            }
+        }
+    }
+    return 0;
 }
 
 /**
@@ -523,11 +578,17 @@ uint8_t TskAuto::isDir(TSK_FS_FILE * a_fs_file)
  */
 uint8_t TskAuto::isFile(TSK_FS_FILE * a_fs_file)
 {
-    if ((a_fs_file) && (a_fs_file->name)
-        && (a_fs_file->name->type == TSK_FS_NAME_TYPE_REG))
-        return 1;
-    else
-        return 0;
+    if ((a_fs_file) && (a_fs_file->name)) {
+        if (a_fs_file->name->type == TSK_FS_NAME_TYPE_REG) {
+            return 1;
+        }
+        else if (a_fs_file->name->type == TSK_FS_NAME_TYPE_UNDEF) {
+            if ((a_fs_file->meta) && (a_fs_file->meta->type == TSK_FS_META_TYPE_REG)) {
+                return 1;
+            }
+        }
+    }
+    return 0;
 }
 
 /**
