@@ -64,6 +64,7 @@ class TskAuto {
     virtual uint8_t openImage(TSK_IMG_INFO *);
     virtual void closeImage();
 
+    TSK_OFF_T getImageSize() const;
     uint8_t findFilesInImg();
     uint8_t findFilesInVs(TSK_OFF_T start);
     uint8_t findFilesInVs(TSK_OFF_T start, TSK_VS_TYPE_ENUM vtype);
@@ -71,6 +72,7 @@ class TskAuto {
     uint8_t findFilesInFs(TSK_OFF_T start, TSK_FS_TYPE_ENUM ftype);
     uint8_t findFilesInFs(TSK_OFF_T start, TSK_INUM_T inum);
     uint8_t findFilesInFs(TSK_OFF_T start, TSK_FS_TYPE_ENUM ftype, TSK_INUM_T inum);
+    uint8_t findFilesInFs(TSK_FS_INFO * a_fs_info);
     TSK_RETVAL_ENUM findFilesInFsRet(TSK_OFF_T start, TSK_FS_TYPE_ENUM a_ftype);
 
     void setFileFilterFlags(TSK_FS_DIR_WALK_FLAG_ENUM);
@@ -124,6 +126,15 @@ class TskAuto {
     virtual TSK_RETVAL_ENUM processFile(TSK_FS_FILE * fs_file,
         const char *path) = 0;
 
+    /**
+     * TskAuto calls this method when it encounters issues while processing an image,
+     * e.g. when opening various volume and file systems fail. This method allows users
+     * of the TskAuto class to choose an appropriate mechanism to present this information.
+     * The implementation of this method in the base class is a no-op.
+     *
+     * @param msg A text message describing the issue that was encountered.
+     */
+    virtual void handleNotification(const char * msg) {};
 
   private:
     TSK_VS_PART_FLAG_ENUM m_volFilterFlags;
