@@ -357,6 +357,8 @@ ffs_dinode_copy(FFS_INFO * ffs, TSK_FS_META * fs_meta)
         fs_meta->atime = tsk_gets32(fs->endian, in->di_atime);
         fs_meta->ctime = tsk_gets32(fs->endian, in->di_ctime);
         fs_meta->crtime = 0;
+        fs_meta->mtime_nano = fs_meta->atime_nano = fs_meta->ctime_nano =
+            fs_meta->crtime_nano = 0;
 
         if (fs_meta->content_len < FFS_FILE_CONTENT_LEN) {
             if ((fs_meta =
@@ -492,6 +494,8 @@ ffs_dinode_copy(FFS_INFO * ffs, TSK_FS_META * fs_meta)
         fs_meta->atime = tsk_gets32(fs->endian, in->di_atime);
         fs_meta->ctime = tsk_gets32(fs->endian, in->di_ctime);
         fs_meta->crtime = 0;
+        fs_meta->mtime_nano = fs_meta->atime_nano = fs_meta->ctime_nano =
+            fs_meta->crtime_nano = 0;
 
         if (fs_meta->content_len < FFS_FILE_CONTENT_LEN) {
             if ((fs_meta =
@@ -614,6 +618,10 @@ ffs_dinode_copy(FFS_INFO * ffs, TSK_FS_META * fs_meta)
         fs_meta->atime = (time_t) tsk_gets64(fs->endian, in->di_atime);
         fs_meta->ctime = (time_t) tsk_gets64(fs->endian, in->di_ctime);
         fs_meta->crtime = 0;
+        fs_meta->mtime_nano = tsk_getu32(fs->endian, in->di_mtimensec);
+        fs_meta->atime_nano = tsk_getu32(fs->endian, in->di_atimensec);
+        fs_meta->ctime_nano = tsk_getu32(fs->endian, in->di_ctimensec);
+        fs_meta->crtime_nano = tsk_getu32(fs->endian, in->di_crtimensec);
 
         if (fs_meta->content_len < FFS_FILE_CONTENT_LEN) {
             if ((fs_meta =
@@ -1642,6 +1650,7 @@ ffs_istat(TSK_FS_INFO * fs, FILE * hFile, TSK_INUM_T inum,
     TSK_FS_FILE *fs_file;
     char ls[12];
     FFS_PRINT_ADDR print;
+    const TSK_FS_ATTR *fs_attr_indir;
 
     // clean up any error messages that are lying around
     tsk_error_reset();
@@ -1664,7 +1673,7 @@ ffs_istat(TSK_FS_INFO * fs, FILE * hFile, TSK_INUM_T inum,
         fs_meta->uid, fs_meta->gid);
 
 
-    tsk_fs_make_ls(fs_meta, ls);
+    tsk_fs_meta_make_ls(fs_meta, ls, sizeof(ls));
     tsk_fprintf(hFile, "mode: %s\n", ls);
 
     tsk_fprintf(hFile, "size: %" PRIuOFF "\n", fs_meta->size);
@@ -1825,6 +1834,24 @@ ffs_istat(TSK_FS_INFO * fs, FILE * hFile, TSK_INUM_T inum,
     if (print.idx != 0)
         tsk_fprintf(hFile, "\n");
 
+    fs_attr_indir = tsk_fs_file_attr_get_type(fs_file,
+        TSK_FS_ATTR_TYPE_UNIX_INDIR, 0, 0);
+    if (fs_attr_indir) {
+        tsk_fprintf(hFile, "\nIndirect Blocks:\n");
+
+        print.idx = 0;
+
+        if (tsk_fs_attr_walk(fs_attr_indir, TSK_FS_FILE_WALK_FLAG_AONLY,
+                print_addr_act, (void *) &print)) {
+            tsk_fprintf(hFile, "\nError reading indirect attribute:  ");
+            tsk_error_print(hFile);
+            tsk_error_reset();
+        }
+        else if (print.idx != 0) {
+            tsk_fprintf(hFile, "\n");
+        }
+    }
+
     tsk_fs_file_close(fs_file);
     return 0;
 }
@@ -1928,7 +1955,7 @@ ffs_open(TSK_IMG_INFO * img_info, TSK_OFF_T offset, TSK_FS_TYPE_ENUM ftype)
     fs->offset = offset;
 
     /* Both sbs are the same size */
-    len = roundup(sizeof(ffs_sb1), FFS_DEV_BSIZE);
+    len = roundup(sizeof(ffs_sb1), img_info->sector_size);
     ffs->fs.sb1 = (ffs_sb1 *) tsk_malloc(len);
     if (ffs->fs.sb1 == NULL) {
         fs->tag = 0;
@@ -2042,7 +2069,7 @@ ffs_open(TSK_IMG_INFO * img_info, TSK_OFF_T offset, TSK_FS_TYPE_ENUM ftype)
      */
     fs->first_block = 0;
     fs->last_block = fs->last_block_act = fs->block_count - 1;
-    fs->dev_bsize = FFS_DEV_BSIZE;
+    fs->dev_bsize = img_info->sector_size;
 
     // determine the last block we have in this image
     if ((TSK_DADDR_T) ((img_info->size - offset) / fs->block_size) <
@@ -2096,6 +2123,7 @@ ffs_open(TSK_IMG_INFO * img_info, TSK_OFF_T offset, TSK_FS_TYPE_ENUM ftype)
 
     fs->get_default_attr_type = tsk_fs_unix_get_default_attr_type;
     fs->load_attrs = tsk_fs_unix_make_data_run;
+    fs->name_cmp = tsk_fs_unix_name_cmp;
 
     fs->file_add_meta = ffs_inode_lookup;
     fs->dir_open_meta = ffs_dir_open_meta;
