@@ -181,10 +181,12 @@ tsk_fs_attr_clear(TSK_FS_ATTR * a_fs_attr)
 static uint8_t
 fs_attr_put_name(TSK_FS_ATTR * fs_attr, const char *name)
 {
-    if (name == NULL) {
+    if ((name == NULL) || (strlen(name) == 0)) {
         if (fs_attr->name_size > 0) {
-            fs_attr->name[0] = '\0';
+            free(fs_attr->name);
+            fs_attr->name_size = 0;
         }
+        fs_attr->name = NULL;
         return 0;
     }
 
@@ -362,6 +364,19 @@ tsk_fs_attr_set_run(TSK_FS_FILE * a_fs_file, TSK_FS_ATTR * a_fs_attr,
     return 0;
 }
 
+static void
+dump_attr(TSK_FS_ATTR *a_fs_attr)
+{
+    TSK_FS_ATTR_RUN *cur_run;
+    cur_run = a_fs_attr->nrd.run;
+
+    fprintf(stderr, "Attribute Run Dump:\n");
+    for (cur_run = a_fs_attr->nrd.run; cur_run; cur_run = cur_run->next) {
+        fprintf(stderr, "  %"PRIuDADDR" to %"PRIuDADDR" %sFiller\n", 
+                cur_run->offset, cur_run->offset + cur_run->len - 1,
+                (cur_run->flags & TSK_FS_ATTR_RUN_FLAG_FILLER)?"":"Not");
+    }
+}
 
 /**
  * \internal
@@ -447,6 +462,7 @@ tsk_fs_attr_add_run(TSK_FS_INFO * a_fs, TSK_FS_ATTR * a_fs_attr,
                     PRIuOFF ") is larger than FILLER (%" PRIuOFF ") (%"
                     PRIuINUM ")", a_data_run_new->offset,
                     data_run_cur->offset, a_fs_attr->fs_file->meta->addr);
+                dump_attr(a_fs_attr);
                 return 1;
             }
 
@@ -530,7 +546,6 @@ tsk_fs_attr_add_run(TSK_FS_INFO * a_fs, TSK_FS_ATTR * a_fs_attr,
      * At this point data_run_prev is the end of the existing list or
      * 0 if there is no list
      */
-
     /* This is an error condition.  
      * It means that we cycled through the existing runs,
      * ended at a VCN that is larger than what we are adding,
@@ -555,6 +570,7 @@ tsk_fs_attr_add_run(TSK_FS_INFO * a_fs, TSK_FS_ATTR * a_fs_attr,
             "): No filler entry for %" PRIuDADDR ". Final: %" PRIuDADDR,
             a_fs_attr->fs_file->meta->addr, a_data_run_new->offset,
             data_run_prev->offset + data_run_prev->len);
+        dump_attr(a_fs_attr);
         return 1;
     }
 
@@ -1050,8 +1066,10 @@ tsk_fs_attr_read(const TSK_FS_ATTR * a_fs_attr, TSK_OFF_T a_offset,
         size_t len_remain;      // length remaining to copy
         size_t len_toread;      // length total to copy
 
-        if (((a_flags & TSK_FS_FILE_READ_FLAG_SLACK) && (a_offset >= a_fs_attr->nrd.allocsize)) ||
-            (!(a_flags & TSK_FS_FILE_READ_FLAG_SLACK) && (a_offset >= a_fs_attr->size))) {
+        if (((a_flags & TSK_FS_FILE_READ_FLAG_SLACK)
+                && (a_offset >= a_fs_attr->nrd.allocsize))
+            || (!(a_flags & TSK_FS_FILE_READ_FLAG_SLACK)
+                && (a_offset >= a_fs_attr->size))) {
             tsk_error_reset();
             tsk_errno = TSK_ERR_FS_READ_OFF;
             snprintf(tsk_errstr, TSK_ERRSTR_L,
@@ -1102,11 +1120,12 @@ tsk_fs_attr_read(const TSK_FS_ATTR * a_fs_attr, TSK_OFF_T a_offset,
 
             // see if we need to read the rest of this run and into the next or if it is all here
             len_inrun = len_remain;
-            if ((data_run_cur->len - blkoffset_inrun) * fs->block_size - byteoffset_toread <
-                len_remain)
+            if ((data_run_cur->len - blkoffset_inrun) * fs->block_size -
+                byteoffset_toread < len_remain)
                 len_inrun =
                     (size_t) ((data_run_cur->len -
-                        blkoffset_inrun) * fs->block_size - byteoffset_toread) ;
+                        blkoffset_inrun) * fs->block_size -
+                    byteoffset_toread);
 
             /* sparse files/runs just get 0s */
             if (data_run_cur->flags & TSK_FS_ATTR_RUN_FLAG_SPARSE) {
@@ -1172,9 +1191,10 @@ tsk_fs_attr_read(const TSK_FS_ATTR * a_fs_attr, TSK_OFF_T a_offset,
                             byteoffset_toread + len_inrun) >
                         a_fs_attr->nrd.initsize)
                     && ((a_flags & TSK_FS_FILE_READ_FLAG_SLACK) == 0)) {
-                    
-                    size_t uninit_off = a_fs_attr->nrd.initsize - 
-                        ((data_run_cur->offset + blkoffset_inrun) * fs->block_size +
+
+                    size_t uninit_off = a_fs_attr->nrd.initsize -
+                        ((data_run_cur->offset +
+                            blkoffset_inrun) * fs->block_size +
                         byteoffset_toread);
 
                     memset(&a_buf[len_toread - len_remain + uninit_off], 0,
