@@ -110,6 +110,7 @@ tsk_fs_name_reset(TSK_FS_NAME * a_fs_name)
 
     a_fs_name->meta_addr = 0;
     a_fs_name->meta_seq = 0;
+    a_fs_name->par_addr = 0;
     a_fs_name->type = 0;
     a_fs_name->flags = 0;
 }
@@ -194,6 +195,7 @@ tsk_fs_name_copy(TSK_FS_NAME * a_fs_name_to,
 
     a_fs_name_to->meta_addr = a_fs_name_from->meta_addr;
     a_fs_name_to->meta_seq = a_fs_name_from->meta_seq;
+    a_fs_name_to->par_addr = a_fs_name_from->par_addr;
     a_fs_name_to->type = a_fs_name_from->type;
     a_fs_name_to->flags = a_fs_name_from->flags;
 
@@ -338,6 +340,8 @@ tsk_fs_name_print(FILE * hFile, const TSK_FS_FILE * fs_file,
     const char *a_path, TSK_FS_INFO * fs, const TSK_FS_ATTR * fs_attr,
     uint8_t print_path)
 {
+    size_t i;
+
     /* type of file - based on dentry type */
     if (fs_file->name->type < TSK_FS_NAME_TYPE_STR_MAX)
         tsk_fprintf(hFile, "%s/",
@@ -391,10 +395,21 @@ tsk_fs_name_print(FILE * hFile, const TSK_FS_FILE * fs_file,
                 name->flags & TSK_FS_NAME_FLAG_UNALLOC)) ? "(realloc)" :
         "");
 
-    if ((print_path) && (a_path != NULL))
-        tsk_fprintf(hFile, "%s", a_path);
+    if ((print_path) && (a_path != NULL)) {
+        for (i = 0; i < strlen(a_path); i++) {
+            if (TSK_IS_CNTRL(a_path[i]))
+                tsk_fprintf(hFile, "^");
+            else
+                tsk_fprintf(hFile, "%c", a_path[i]);
+        }
+    }
 
-    tsk_fprintf(hFile, "%s", fs_file->name->name);
+    for (i = 0; i < strlen(fs_file->name->name); i++) {
+        if (TSK_IS_CNTRL(fs_file->name->name[i]))
+            tsk_fprintf(hFile, "^");
+        else
+            tsk_fprintf(hFile, "%c", fs_file->name->name[i]);
+    }
 
 /*  This will add the short name in parentheses
     if (fs_file->name->shrt_name != NULL && fs_file->name->shrt_name[0] != '\0')
@@ -402,12 +417,17 @@ tsk_fs_name_print(FILE * hFile, const TSK_FS_FILE * fs_file,
 */
 
     /* print the data stream name if we the non-data NTFS stream */
-    if (fs_attr) {
-        if (((fs_attr->type == TSK_FS_ATTR_TYPE_NTFS_DATA) &&
-                (strcmp(fs_attr->name, "$Data") != 0)) ||
-            ((fs_attr->type == TSK_FS_ATTR_TYPE_NTFS_IDXROOT) &&
-                (strcmp(fs_attr->name, "$I30") != 0)))
-            tsk_fprintf(hFile, ":%s", fs_attr->name);
+    if ((fs_attr) && (fs_attr->name)) {
+        if ((fs_attr->type != TSK_FS_ATTR_TYPE_NTFS_IDXROOT) ||
+            (strcmp(fs_attr->name, "$I30") != 0)) {
+            tsk_fprintf(hFile, ":");
+            for (i = 0; i < strlen(fs_attr->name); i++) {
+                if (TSK_IS_CNTRL(fs_attr->name[i]))
+                    tsk_fprintf(hFile, "^");
+                else
+                    tsk_fprintf(hFile, "%c", fs_attr->name[i]);
+            }
+        }
     }
 
     return;
@@ -425,7 +445,7 @@ tsk_fs_name_print(FILE * hFile, const TSK_FS_FILE * fs_file,
 void
 tsk_fs_name_print_long(FILE * hFile, const TSK_FS_FILE * fs_file,
     const char *a_path, TSK_FS_INFO * fs, const TSK_FS_ATTR * fs_attr,
-    uint8_t print_path)
+    uint8_t print_path, int32_t sec_skew)
 {
     tsk_fs_name_print(hFile, fs_file, a_path, fs, fs_attr, print_path);
 
@@ -447,20 +467,29 @@ tsk_fs_name_print_long(FILE * hFile, const TSK_FS_FILE * fs_file,
 
         /* MAC times */
         tsk_fprintf(hFile, "\t");
-        tsk_fs_print_time(hFile, fs_file->meta->mtime);
+        if (fs_file->meta->mtime)
+            tsk_fs_print_time(hFile, fs_file->meta->mtime - sec_skew);
+        else
+            tsk_fs_print_time(hFile, fs_file->meta->mtime);
 
         tsk_fprintf(hFile, "\t");
         /* FAT only gives the day of last access */
-        if (TSK_FS_TYPE_ISFAT(fs->ftype))
+        if ((TSK_FS_TYPE_ISFAT(fs->ftype)) || (fs_file->meta->atime == 0))
             tsk_fs_print_day(hFile, fs_file->meta->atime);
         else
-            tsk_fs_print_time(hFile, fs_file->meta->atime);
+            tsk_fs_print_time(hFile, fs_file->meta->atime - sec_skew);
 
         tsk_fprintf(hFile, "\t");
-        tsk_fs_print_time(hFile, fs_file->meta->ctime);
+        if (fs_file->meta->ctime)
+            tsk_fs_print_time(hFile, fs_file->meta->ctime - sec_skew);
+        else
+            tsk_fs_print_time(hFile, fs_file->meta->ctime);
 
         tsk_fprintf(hFile, "\t");
-        tsk_fs_print_time(hFile, fs_file->meta->crtime);
+        if (fs_file->meta->crtime)
+            tsk_fs_print_time(hFile, fs_file->meta->crtime - sec_skew);
+        else
+            tsk_fs_print_time(hFile, fs_file->meta->crtime);
 
         /* use the stream size if one was given */
         if (fs_attr)
@@ -480,27 +509,26 @@ tsk_fs_name_print_long(FILE * hFile, const TSK_FS_FILE * fs_file,
  * \internal
  *
 ** Print output in the format that mactime reads.
-** This allows the deleted files to be inserted to get a better
-** picture of what happened
-**
-** Prepend a_path when printing full file name
-**  dir needs to end with "/" 
-**
-** prepend *prefix to path as the mounting point that the original
-** grave-robber was run on
 **
 ** If the flags in the fs_file->meta structure are set to FS_FLAG_ALLOC
 ** then it is assumed that the inode has been reallocated and the
 ** contents are not displayed
 **
-** fs is not required (only used for block size).  
+** fs is not required (only used for block size).
+ * @param hFile handle to print results to
+ * @param fs_file File to print details about
+ * @param a_path Parent directory of file (needs to end with "/")
+ * @param fs_attr Attribute in file that is being called for (NULL for non-NTFS)
+ * @param prefix Path of mounting point for image
+ * @param time_skew number of seconds skew to adjust time
 */
 void
 tsk_fs_name_print_mac(FILE * hFile, const TSK_FS_FILE * fs_file,
-    const char *a_path, TSK_FS_INFO * fs, const TSK_FS_ATTR * fs_attr,
-    const char *prefix)
+    const char *a_path, const TSK_FS_ATTR * fs_attr,
+    const char *prefix, int32_t time_skew)
 {
     char ls[12];
+    size_t i;
 
     if ((!hFile) || (!fs_file))
         return;
@@ -509,14 +537,37 @@ tsk_fs_name_print_mac(FILE * hFile, const TSK_FS_FILE * fs_file,
     tsk_fprintf(hFile, "0|");
 
     /* file name */
-    tsk_fprintf(hFile, "%s%s%s", prefix, a_path, fs_file->name->name);
+    tsk_fprintf(hFile, "%s", prefix);
+
+    // remove any control chars as we print the names
+    if (a_path != NULL) {
+        for (i = 0; i < strlen(a_path); i++) {
+            if (TSK_IS_CNTRL(a_path[i]))
+                tsk_fprintf(hFile, "^");
+            else
+                tsk_fprintf(hFile, "%c", a_path[i]);
+        }
+    }
+
+    for (i = 0; i < strlen(fs_file->name->name); i++) {
+        if (TSK_IS_CNTRL(fs_file->name->name[i]))
+            tsk_fprintf(hFile, "^");
+        else
+            tsk_fprintf(hFile, "%c", fs_file->name->name[i]);
+    }
 
     /* print the data stream name if it exists and is not the default NTFS */
-    if ((fs_attr) && (((fs_attr->type == TSK_FS_ATTR_TYPE_NTFS_DATA) &&
-                (strcmp(fs_attr->name, "$Data") != 0)) ||
-            ((fs_attr->type == TSK_FS_ATTR_TYPE_NTFS_IDXROOT) &&
-                (strcmp(fs_attr->name, "$I30") != 0))))
-        tsk_fprintf(hFile, ":%s", fs_attr->name);
+    if ((fs_attr) && (fs_attr->name) &&
+        ((fs_attr->type != TSK_FS_ATTR_TYPE_NTFS_IDXROOT) ||
+            (strcmp(fs_attr->name, "$I30") != 0))) {
+        tsk_fprintf(hFile, ":");
+        for (i = 0; i < strlen(fs_attr->name); i++) {
+            if (TSK_IS_CNTRL(fs_attr->name[i]))
+                tsk_fprintf(hFile, "^");
+            else
+                tsk_fprintf(hFile, "%c", fs_attr->name[i]);
+        }
+    }
 
     if ((fs_file->meta)
         && (fs_file->meta->type == TSK_FS_META_TYPE_LNK)
@@ -568,11 +619,24 @@ tsk_fs_name_print_mac(FILE * hFile, const TSK_FS_FILE * fs_file,
             tsk_fprintf(hFile, "%" PRIuOFF "|", fs_file->meta->size);
 
         /* atime, mtime, ctime, crtime */
-        tsk_fprintf(hFile,
-            "%" PRIu32 "|%" PRIu32 "|%" PRIu32 "|%" PRIu32 "\n",
-            (uint32_t) fs_file->meta->atime,
-            (uint32_t) fs_file->meta->mtime,
-            (uint32_t) fs_file->meta->ctime,
-            (uint32_t) fs_file->meta->crtime);
+        if (fs_file->meta->atime)
+            tsk_fprintf(hFile, "%" PRIu32 "|", fs_file->meta->atime - time_skew);
+        else
+            tsk_fprintf(hFile, "%" PRIu32 "|", fs_file->meta->atime);
+
+        if (fs_file->meta->mtime)
+            tsk_fprintf(hFile, "%" PRIu32 "|", fs_file->meta->mtime - time_skew);
+        else
+            tsk_fprintf(hFile, "%" PRIu32 "|", fs_file->meta->mtime);
+        
+        if (fs_file->meta->ctime)
+            tsk_fprintf(hFile, "%" PRIu32 "|", fs_file->meta->ctime - time_skew);
+        else
+            tsk_fprintf(hFile, "%" PRIu32 "|", fs_file->meta->ctime);
+        
+        if (fs_file->meta->crtime)
+            tsk_fprintf(hFile, "%" PRIu32 "\n", fs_file->meta->crtime - time_skew);
+        else
+            tsk_fprintf(hFile, "%" PRIu32 "\n", fs_file->meta->crtime);
     }
 }
