@@ -137,7 +137,7 @@ extern "C" {
     extern TSK_FS_FILE *tsk_fs_file_alloc(TSK_FS_INFO *);
 
     /* FS_DIR */
-    extern TSK_FS_DIR *tsk_fs_dir_alloc(TSK_FS_INFO * a_fs, size_t a_cnt);
+    extern TSK_FS_DIR *tsk_fs_dir_alloc(TSK_FS_INFO * a_fs, TSK_INUM_T a_addr, size_t a_cnt);
     extern uint8_t tsk_fs_dir_realloc(TSK_FS_DIR * a_fs_dir, size_t a_cnt);
     extern uint8_t tsk_fs_dir_add(TSK_FS_DIR * a_fs_dir,
         const TSK_FS_NAME * a_fs_dent);
@@ -151,12 +151,6 @@ extern "C" {
         TSK_FS_NAME * a_fs_name);
     extern TSK_RETVAL_ENUM tsk_fs_dir_find_orphans(TSK_FS_INFO * a_fs,
         TSK_FS_DIR * a_fs_dir);
-    /* we are using the last inode as the special inode for the orphan directory.  Note that this
-     * macro is defined to abstract this convention, but there are many places in the code where
-     * there is implied logic about this convention. For example, inode_walks will stop before
-     * this value so that special handling can occur. */
-#define TSK_FS_ORPHANDIR_INUM(fs_info) \
-    (fs_info->last_inum)
 
 
 
@@ -168,10 +162,10 @@ extern "C" {
     extern void tsk_fs_name_print(FILE *, const TSK_FS_FILE *,
         const char *, TSK_FS_INFO *, const TSK_FS_ATTR *, uint8_t);
     extern void tsk_fs_name_print_long(FILE *, const TSK_FS_FILE *,
-        const char *, TSK_FS_INFO *, const TSK_FS_ATTR *, uint8_t);
+        const char *, TSK_FS_INFO *, const TSK_FS_ATTR *, uint8_t,
+        int32_t);
     extern void tsk_fs_name_print_mac(FILE *, const TSK_FS_FILE *,
-        const char *, TSK_FS_INFO *, const TSK_FS_ATTR * fs_attr,
-        const char *);
+        const char *, const TSK_FS_ATTR * fs_attr, const char *, int32_t);
     extern uint8_t tsk_fs_name_copy(TSK_FS_NAME * a_fs_name_to,
         const TSK_FS_NAME * a_fs_name_from);
     extern void tsk_fs_name_reset(TSK_FS_NAME * a_fs_name);
