@@ -19,7 +19,8 @@
 #include <afflib/afflib.h>
 #include <afflib/afflib_i.h>
 
-extern TSK_IMG_INFO *aff_open(const char **);
+extern TSK_IMG_INFO *aff_open(const char *const images[],
+    unsigned int a_ssize);
 
 /** \internal
  * Stores AFF-specific data
