@@ -142,10 +142,11 @@ raw_close(TSK_IMG_INFO * img_info)
  * \internal
  * Open the file as a raw image.  
  * @param image Path to disk image to open.
+ * @param a_ssize Size of device sector in bytes (or 0 for default)
  * @returns NULL on error.
  */
 TSK_IMG_INFO *
-raw_open(const TSK_TCHAR * image)
+raw_open(const TSK_TCHAR * image, unsigned int a_ssize)
 {
     IMG_RAW_INFO *raw_info;
     TSK_IMG_INFO *img_info;
@@ -163,6 +164,10 @@ raw_open(const TSK_TCHAR * image)
     img_info->close = raw_close;
     img_info->imgstat = raw_imgstat;
 
+    img_info->sector_size = 512;
+    if (a_ssize)
+        img_info->sector_size = a_ssize;
+
 
 #if defined(TSK_WIN32) || defined(__CYGWIN__)
     if ((image[0] == _TSK_T('\\'))
@@ -178,7 +183,7 @@ raw_open(const TSK_TCHAR * image)
             tsk_error_reset();
             tsk_errno = TSK_ERR_IMG_STAT;
             snprintf(tsk_errstr, TSK_ERRSTR_L,
-                "raw_open directory check: %s", strerror(errno));
+                "raw_open: %s", strerror(errno));
             return NULL;
         }
         else if ((stat_buf.st_mode & S_IFMT) == S_IFDIR) {
@@ -189,7 +194,7 @@ raw_open(const TSK_TCHAR * image)
             tsk_error_reset();
             tsk_errno = TSK_ERR_IMG_MAGIC;
             snprintf(tsk_errstr, TSK_ERRSTR_L,
-                "raw_open: Image is a directory");
+                "raw_open: path is for a directory");
             return NULL;
         }
     }
@@ -198,27 +203,46 @@ raw_open(const TSK_TCHAR * image)
     {
         DWORD dwHi, dwLo;
 
-        if ((raw_info->fd = CreateFile(image, GENERIC_READ,
-                    FILE_SHARE_READ, 0, OPEN_EXISTING, 0, 0)) ==
+        if ((raw_info->fd = CreateFile(image, FILE_READ_DATA,
+                    FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL)) ==
             INVALID_HANDLE_VALUE) {
 
-            // if it is a device, try SHARE_WRITE
+            // if it is a device, try with SHARE_WRITE
             if ((image[0] == _TSK_T('\\')) && (image[1] == _TSK_T('\\')) &&
                 (image[2] == _TSK_T('.')) && (image[3] == _TSK_T('\\'))) {
                 if (tsk_verbose)
                     tsk_fprintf(stderr,
                         "raw_open: Trying Windows device with share_write mode\n");
 
-                raw_info->fd = CreateFile(image, GENERIC_READ,
-                    FILE_SHARE_READ | FILE_SHARE_WRITE, 0, OPEN_EXISTING, 0, 0);
+                raw_info->fd = CreateFile(image, FILE_READ_DATA,
+                    FILE_SHARE_READ | FILE_SHARE_WRITE, NULL,
+                    OPEN_EXISTING, 0, NULL);
             }
 
             if (raw_info->fd == INVALID_HANDLE_VALUE) {
                 tsk_error_reset();
                 tsk_errno = TSK_ERR_IMG_OPEN;
-                snprintf(tsk_errstr, TSK_ERRSTR_L,
-                    "raw_open file: %" PRIttocTSK " msg: %d", image,
-                    (int)GetLastError());
+                // print string of commonly found errors
+                if (GetLastError() == ERROR_ACCESS_DENIED) {
+                    snprintf(tsk_errstr, TSK_ERRSTR_L,
+                        "raw_open file: %" PRIttocTSK " (Access Denied)",
+                        image);
+                }
+                else if (GetLastError() == ERROR_SHARING_VIOLATION) {
+                    snprintf(tsk_errstr, TSK_ERRSTR_L,
+                        "raw_open file: %" PRIttocTSK
+                        " (Sharing Violation)", image);
+                }
+                else if (GetLastError() == ERROR_FILE_NOT_FOUND) {
+                    snprintf(tsk_errstr, TSK_ERRSTR_L,
+                        "raw_open file: %" PRIttocTSK " (File not found)",
+                        image);
+                }
+                else {
+                    snprintf(tsk_errstr, TSK_ERRSTR_L,
+                        "raw_open file: %" PRIttocTSK " (%d)", image,
+                        (int) GetLastError());
+                }
                 return NULL;
             }
         }
@@ -233,7 +257,7 @@ raw_open(const TSK_TCHAR * image)
                 tsk_errno = TSK_ERR_IMG_OPEN;
                 snprintf(tsk_errstr, TSK_ERRSTR_L,
                     "raw_open file: %" PRIttocTSK " GetFileSize: %d",
-                    image, (int)GetLastError());
+                    image, (int) GetLastError());
                 return NULL;
             }
             img_info->size = dwLo | ((TSK_OFF_T) dwHi << 32);
@@ -250,7 +274,7 @@ raw_open(const TSK_TCHAR * image)
                 tsk_errno = TSK_ERR_IMG_OPEN;
                 snprintf(tsk_errstr, TSK_ERRSTR_L,
                     "raw_open file: %" PRIttocTSK
-                    " DeviceIoControl: %d", image, (int)GetLastError());
+                    " DeviceIoControl: %d", image, (int) GetLastError());
                 return NULL;
             }
 
@@ -271,13 +295,13 @@ raw_open(const TSK_TCHAR * image)
         return NULL;
     }
 
-    /* We don't use the stat output because it doesn't work on raw
-     * devices and such */
-    img_info->size = lseek(raw_info->fd, 0, SEEK_END);
-    lseek(raw_info->fd, 0, SEEK_SET);
-
 #if defined(__APPLE__)
-    /* OS X doesn't support SEEK_END on devices */
+    /* OS X doesn't support SEEK_END on char devices */
+    if ((stat_buf.st_mode & S_IFMT) != S_IFCHR) {
+        img_info->size = lseek(raw_info->fd, 0, SEEK_END);
+        lseek(raw_info->fd, 0, SEEK_SET);
+    }
+
     if (img_info->size == 0) {
         int blkSize;
         long long blkCnt;
@@ -288,7 +312,12 @@ raw_open(const TSK_TCHAR * image)
             }
         }
     }
-#endif                          // apple
+#else
+    /* We don't use the stat output because it doesn't work on raw
+     * devices and such */
+    img_info->size = lseek(raw_info->fd, 0, SEEK_END);
+    lseek(raw_info->fd, 0, SEEK_SET);
+#endif
 
 #endif
     raw_info->seek_pos = 0;
